@@ -277,11 +277,10 @@ class ClassifyStage(REStage):
     __SAVE_Classify_Best__ = "__SAVE_Classify_Best__"
     __SAVE_Classify_result__ = "__SAVE_Classify_result__"
 
-    @classmethod
-    def get_classify_text(cls, text, rules):
+    def get_classify_text(self, text, rules):
         re_dict = {}
         for (rule, entity_name) in rules:
-            entities = cls.__get_entity__(rule, text)
+            entities = self.__get_entity__(rule, text)
             if len(entities) > 0:
                 re_dict[entity_name] = 1.0
             else:
